==> question2answer-1.5-language-pt-BR.zip: pt/qa-lang-admin.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-admin.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for admin center


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'active_widgets_explanation' => 'Widgets ativos:',
		'add_category_button' => 'Adicionar Categoria',
		'add_field_button' => 'Adicionar Campo',
		'add_link_button' => 'Adicionar LInk',
		'add_link_link' => ' - ^1adicionar link^2',
		'add_new_field' => 'Adicionar novo campo',
		'add_new_title' => 'Adicionar novo título',
		'add_page_button' => 'Adicionar Página',
		'add_title_button' => 'Adicionar Título',
		'add_widget_button' => 'Adicionar Widget',
		'add_widget_link' => ' - ^1adicionar widget^2',
		'admin_title' => 'Painel administrativo',
		'after_footer' => 'Após links do rodapé',
		'after_main_menu' => 'Após links do topo',
		'after_x_tab' => 'Após "^"',
		'after_x' => 'Após "^"',
		'moderate_title' => 'Moderar',
		'basic_editor' => 'Editor Básico',
		'before_main_menu' => 'Antes dos links do topo',
		'block_ips_note' => 'Use um hífen para intervalos ou * para variáveis. Exemplos: 192.168.0.4 , 192.168.0.0-192.168.0.31 , 192.168.0.*',
		'block_words_note' => 'Use o * como variável. Exemplos: doh (bloqueia apenas o termo doh) , doh* (bloqueia tnato doh quanto dohno) , do*h (bloqueia doh, dooh e dough).',
		'cancel_mailing_button' => 'Cancelar Enviador de Emails',
		'categories_introduction' => 'Para usar categorias, clique no botão \'Add Category\'.',
		'categories_not_shown' => 'Algumas perguntas estão em categorias que não serão mostradas.',
		'categories_title' => 'Categorias',
		'categories' => 'Categorias',
		'category_add_sub' => 'adicionar sub-categoria',
		'category_added' => 'Categoria adicionada',
		'category_already_used' => 'Isto já está em uso por uma categoria',
		'category_default_slug' => 'categoria-^',
		'category_description' => 'Descrição opcional de categoria:',
		'category_max_depth_x' => 'Algumas opções podem estar ocultas para prevenir que uma categoria tenha mais de ^ níveis.',
		'category_move_parent' => 'transferir para outra categoria-pai',
		'category_name_first' => 'Nome da primeira categoria:',
		'category_name' => 'Nome da categoria:',
		'category_no_add_subs_x' => 'Esta categoria não pode ter mais categorias porque já possui ^ níveis de profundidade.',
		'category_no_delete_subs' => 'Esta categoria não pode ser removida porque possui uma sub-categoria.',
		'category_no_sub_error' => '^q pergunta/s nesta categoria não possuem sub-categorias - ^1escolher sub-categoria^2',
		'category_no_sub_to' => 'Transferir perguntas em ^ sem sub-categorias para:',
		'category_no_subs' => 'Nada',
		'category_none_error' => '^q pergunta/s não possuem categorias - ^1escolher sub-categoria^2',
		'category_none_to' => 'Transferir perguntas sem categorias para:',
		'category_parent' => 'Categoria-pai:',
		'category_saved' => 'Categoria salva',
		'category_slug' => 'Categoria slug - Fragmento de URL:',
		'category_subs' => 'Sub-categorias:',
		'category_top_level' => 'Sem categoria-pai (primeiro nível)',
		'characters' => 'caracteres',
		'check_language_suffix' => ' - ^1conferir arquivos de idioma^2',
		'click_name_edit' => 'Páginas ou links customizados:',
		'database_cleanup' => 'Operações de limpeza de banco de dados',
		'delete_category_reassign' => 'Remover esta categoria e reclassicar as perguntas para:',
		'delete_category' => 'Remover esta categoria',
		'delete_field' => 'Remover este campo',
		'delete_hidden_complete' => 'Todos as publicações ocultas sem dependências foram removidas',
		'delete_hidden_note' => ' - todas as perguntas, respostas e comentários ocultos sem dependências',
		'delete_hidden' => 'Excluir todas as publicações ocultas',
		'delete_link' => 'Excluir este link',
		'delete_page' => 'Excluir esta página',
		'delete_stop' => 'Interromper exclusão',
		'delete_title' => 'Remover este título',
		'delete_widget_position' => 'Remover este widget desta posição',
		'edit_custom_page' => 'Editar página customizada',
		'edit_field' => ' - ^1editar campo^2',
		'edit_link' => ' - ^1editar link^2',
		'edit_page' => ' - ^1editar página^2',
		'edit_title' => ' - ^1editar título^2',
		'emails_per_minute' => 'emails por minuto',
		'emails_title' => 'Emails',
		'feed_link_example' => 'Exemplo de feed',
		'feed_link' => 'Feed',
		'feeds_title' => 'RSS feeds',
		'field_link_url' => 'URLs linkados',
		'field_multi_line' => 'Múltiplas linhas de texto',
		'field_name' => 'Nome do campo:',
		'field_single_line' => 'Linha única de texto',
		'field_type' => 'Tipo de conteúdo:',
		'first' => 'Primeiro',
		'flagged_title' => 'Denunciado',
		'from_anon' => 'De anônimo:',
		'from_users' => 'De usuários:',
		'general_title' => 'Geral',
		'hidden_answers_deleted' => 'Excluídas ^1 de ^2 respostas ocultas sem dependências...',
		'hidden_comments_deleted' => 'Excluídos ^1 de ^2 comentários ocultos...',
		'hidden_questions_deleted' => 'Excluídas ^1 de ^2 perguntas sem dependências...',
		'hotness_factors' => 'Importância relativa para a popularidade de perguntas:',
		'hidden_title' => 'Oculto',
		'installed_plugins' => 'Plugins instalados:',
		'ip_address_pages' => 'Página de endereços IP',
		'layout_title' => 'Aparência',
		'link_name' => 'Texto do link:',
		'link_new_window' => 'Abrir link em nova janela',
		'link_url' => 'Endereço do link - absoluto ou relativo à raiz do Q2A:',
		'lists_title' => 'Listas',
		'mailing_complete' => 'O envio de emails foi concluído',
		'mailing_explanation' => 'Usuários podem remover a inscrição ao envio de emails na página de usuário deles.',
		'mailing_progress' => 'Envio completo para ^1 de ^2 usuários...',
		'mailing_title' => 'Envio de emails',
		'mailing_unsubscribe' => 'Um link para remover a inscrição será acrescentado no rodapé de cada mensagem.',
		'maintenance_admin_only' => 'Seu site está em ^1manutenção^2 e está inacessível para usuários comuns.',
		'maximum_x' => ' (máximo ^)',
		'module_x_database_init' => 'Os módulos ^1 ^2 requerem ^3database initialization^4.',
		'most_flagged_title' => 'Conteúdo denunciado',
		'mysql_version' => 'Versão do MySQL:',
		'nav_links_explanation' => 'Mostrar links de navegação:',
		'nav_qa_is_home' => 'Início (linka para a página inicial)',
		'neat_urls_note' => ' (requer arquivo ^1htaccess^2)',
		'no_approve_found' => 'Nenhum conteúdo aguarda aprovação',
		'no_classification' => 'Nenhuma',
		'no_flagged_found' => 'Nenhum conteúdo denunciado encontrado',
		'no_hidden_found' => 'Nenhum conteúdo oculto encontrado',
		'no_image_gd' => 'A versão instalada do PHP foi compilada sem suporte a GD image, o que impede o envio direto de avatares pelos usuários.',
		'no_link' => 'Nenhum link',
		'no_multibyte' => 'A versão instalada do PHP foi compilada sem suporte a multibyte string. A busca será menos eficaz para caracteres não românicos.',
		'no_plugin_options' => 'Nenhum dos plugins instalados tem opções a exibir.',
		'no_privileges' => 'Somente administradores podem acessar esta página.',
		'not_logged_in' => 'Por favor ^1entre^2 como administrador para acessar esta página.',
		'opposite_main_menu' => 'Canto direito dos links do topo',
		'options_reset' => 'Opções restauradas',
		'options_saved' => 'Opções salvas',
		'options' => 'opções',
		'page_already_used' => 'Isto já está em uso por uma página',
		'page_content_html' => 'Conteúdo a ser divulgado na página - HTML permitido:',
		'page_default_slug' => 'página-^',
		'page_heading' => 'Cabeçalho a ser exibido no topo de página:',
		'page_name' => 'Nome da página (também usado para o link):',
		'page_slug' => 'Slug da página (Fragmento de URL):',
		'pages_explanation' => 'Clique no botão \'Add Page\' para acrescentar conteúdo customizado ao seu site Q2A, ou \'Add Link\' para linkar a sites externos.',
		'pages_title' => 'Páginas',
		'pause_mailing_button' => 'Interromper envio',
		'per_ip_hour' => 'por IP/hora',
		'per_user_hour' => 'por usuário/hora',
		'permissions_title' => 'Permissões',
		'permit_to_view' => 'Visível para:',
		'php_version' => 'Versão do PHP:',
		'pixels' => 'pixels',
		'plugin_module' => ' (módulo do plugin: ^)',
		'plugin_pages_explanation' => 'Páginas disponíveis via plugins:',
		'plugins_title' => 'Plugins',
		'points_defaults_shown' => 'Padrões mostrados abaixo mas AINDA NÃO APLICADOS:',
		'points_required' => 'Pontos necessários para receber título:',
		'points_title' => 'Pontos',
		'points' => 'pontos',
		'position' => 'Posição:',
		'posting_title' => 'Publicando',
		'profile_fields' => 'Campos adicionais no perfil do usuário:',
		'q2a_build_date' => 'Data da versão:',
		'q2a_db_size' => 'Tamanho do banco de dados:',
		'q2a_db_version' => 'Versão do banco de dados Q2A:',
		'q2a_latest_version' => 'Última versão:',
		'q2a_version' => 'Versão do Question2Answer:',
		'question_lists' => 'Lista de perguntas',
		'question_pages' => 'Páginas de perguntas',
		'recalc_categories_backpaths' => 'Recontando URL paths para ^1 de ^2 categorias...',
		'recalc_categories_complete' => 'Todas as categorias foram recalculadas com sucesso.',
		'recalc_categories_note' => ' - para publicações de categorias e contagem de categorias',
		'recalc_categories_recounting' => 'Recontando perguntas para ^1 de ^2 categorias...',
		'recalc_categories_updated' => 'Recontando para ^1 de ^2 publicações...',
		'recalc_categories' => 'Recontando categorias',
		'recalc_points_complete' => 'Todos os pontos de usuários foram recalculados com sucesso.',
		'recalc_points_note' => ' - para ranking de usuários e divulgação de pontos',
		'recalc_points_recalced' => 'Recalculados ^1 de ^2 usuários...',
		'recalc_points_usercount' => 'Estimando número total de usuários...',
		'recalc_points' => 'Recontando pontos de usuários',
		'recalc_posts_count' => 'Recuperando número total de perguntas, respostas e comentários...',
		'recalc_stop' => 'Interromper recontagem',
		'recent_approve_title' => 'Conteúdo recente aguardando aprovação',
		'recent_hidden_title' => 'Conteúdo recente oculto',
		'recount_posts_as_recounted' => 'Recontadas perguntas e popularidade para ^1 de ^2 publicações...',
		'recount_posts_complete' => 'Todas as publicações foram recontadas com sucesso.',
		'recount_posts_note' => ' - o número de respostas, votos e denúncias para cada publicação',
		'recount_posts_stop' => 'Interromper recontagem',
		'recount_posts_votes_recounted' => 'Recontados os votos e denúncias de ^1 de ^2 publicações...',
		'recount_posts' => 'Recontar publicações',
		'refill_events_complete' => 'Todos os eventos streams foram repreenchidos com sucesso',
		'refill_events_note' => ' - para cada lista de atualização de usuário\'s',
		'refill_events_refilled' => 'Repreenchidas ^1 de ^2 perguntas...',
		'refill_events' => 'Repreencher eventos streams',
		'reindex_content' => 'Reindexar conteúdo',
		'reindex_content_note' => ' - para pesquisa e sugestões de perguntas relacionadas',
		'reindex_content_stop' => 'Interromper reindexação',
		'reindex_pages_reindexed' => 'Reindexadas ^1 de ^2 páginas...',
		'reindex_posts_complete' => 'Todas as publicações foram reindexadas com sucesso.',
		'reindex_posts_reindexed' => 'Reindexados ^1 de ^2 publicações...',
		'reindex_posts_wordcounted' => 'Recontadas ^1 de ^2 palavras...',
		'requires_php_version' => 'Desativado - requer PHP ^ ou superior',
		'requires_q2a_version' => 'Desativado - requer Question2Answer ^ or superior',
		'reset_options_button' => 'Restaurar Padrões',
		'resume_mailing_button' => 'Continuar Envio de Emails',
		'save_options_button' => 'Salvar Opções',
		'save_recalc_button' => 'Salvar e Recontar',
		'send_test_button' => 'Enviar Teste para Mim',
		'show_defaults_button' => 'Mostrar Padrões',
		'slug_bad_chars' => 'O slug não pode conter esses caracteres: ^',
		'slug_reserved' => 'Este slug já está atribuído a outra página',
		'spam_title' => 'Spam',
		'start_mailing_button' => 'Iniciar Envio de Emails',
		'stats_title' => 'Estatísticas',
		'stop_recalc_warning' => 'Uma operação de limpeza do banco de dados está rodando. Se esta página for fechada agora, a operação será interrompida.',
		'tag_pages' => 'Páginas de Tags',
		'tags_and_categories' => 'Tags e Categorias',
		'tags_not_shown' => 'Algumas perguntas possuem tags que não serão mostradas.',
		'tags' => 'Tags',
		'test_sent_to_x' => 'A mensagem de teste foi enviada para ^',
		'title_already_used' => 'Isto já está em uso por outro título',
		'top_level_categories' => 'Categorias de primeiro nível:',
		'total_as' => 'Total de respostas:',
		'total_cs' => 'Total de comentários:',
		'total_qs' => 'Total de perguntas:',
		'unnamed_plugin' => 'Plugin sem nome',
		'upgrade_db' => 'O banco de dados do seu Question2Answer precisa ser ^1atualizado^2 para essa versão.',
		'url_format_note' => 'Opções com ^ estão funcionando para a configuração do seu site. Para um melhor search engine optimization (SEO), use a primeira opção ^ disponível.',
		'user_pages' => 'Páginas de usuários',
		'user_title' => 'Título de usuário - HTML permitido:',
		'user_titles' => 'Títulos de usuários com base em pontos:',
		'users_active' => 'Usuários ativos:',
		'users_must_have' => 'Usuários precisam ter',
		'users_posted' => 'Usuários com publicações:',
		'users_registered' => 'Usuários cadastrados:',
		'users_title' => 'Usuários',
		'users_voted' => 'Usuários que votaram:',
		'version_get_x' => 'recuperar ^',
		'version_requires_php' => '^1 requer PHP ^2', 
		'version_requires_q2a' => '^1 requer Q2A ^2', 
		'version_latest_unknown' => 'última versão desconhecida',
		'version_latest' => 'última',
		'viewing_title' => 'Visualização',
		'widget_all_pages' => 'Mostrar widget nesta posição em todas as páginas disponíveis',
		'widget_global_options' => ' - ^1opções^2',
		'widget_name' => 'Nome do widget:',
		'widget_no_positions' => 'Este widget já foi adicionado a todas as posições disponíveis.',
		'widget_not_available' => 'Este widgt não está disponível. Isto pode ter acontecido porque o plugin que providencia o widget não está mais instalado.',
		'widget_pages_explanation' => 'Mostrar o widget nesta posição para as seguintes páginas:',
		'widgets_explanation' => 'Widgets disponíveis:',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.6-language-pt-BR.zip: pt/qa-lang-admin.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-admin.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for admin center


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'active_widgets_explanation' => 'Widgets ativos:',
		'add_category_button' => 'Adicionar Categoria',
		'add_field_button' => 'Adicionar Campo',
		'add_link_button' => 'Adicionar LInk',
		'add_link_link' => ' - ^1adicionar link^2',
		'add_new_field' => 'Adicionar novo campo',
		'add_new_title' => 'Adicionar novo título',
		'add_page_button' => 'Adicionar Página',
		'add_title_button' => 'Adicionar Título',
		'add_widget_button' => 'Adicionar Widget',
		'add_widget_link' => ' - ^1adicionar widget^2',
		'admin_title' => 'Painel administrativo',
		'after_footer' => 'Após links do rodapé',
		'after_main_menu' => 'Após links do topo',
		'after_x_tab' => 'Após "^"',
		'after_x' => 'Após "^"',
		'moderate_title' => 'Moderar',
		'basic_editor' => 'Editor Básico',
		'before_main_menu' => 'Antes dos links do topo',
		'blobs_directory_error' => "O diretório ^ definido como QA_BLOBS_DIRECTORY não tem permissões de escrita pelo servidor.",
		'blobs_move_complete' => "Migração de imagens e documentos enviados completa.",
		'blobs_move_moved' => "Migrados ^1 de ^2 imagens e documentos enviados",
		'blobs_stop' => "Interromper migração",
		'blobs_to_db' => "Blobs para banco de dados",
		'blobs_to_db_note' => "- migrar todas as imagens e documentos dos arquivos em disco para o banco de dados",
		'blobs_to_disk' => "Blobs para arquivo",
		'blobs_to_disk_note' => "- migrar todas as imagens e documentos do banco de dados para os arquivos em disco",
		'block_button' => "bloquear",
		'form_security_expired' => "Formulário de segurança expirado - tente novamente",
		'approve_users_title' => "Aprovar usuários",
		'no_unapproved_found' => "Nenhum usuário aguardando aprovação",
		'show_on_register_form' => "Mostrar campo no formulário de cadastro",
		'block_ips_note' => 'Use um hífen para intervalos ou * para variáveis. Exemplos: 192.168.0.4 , 192.168.0.0-192.168.0.31 , 192.168.0.*',
		'block_words_note' => 'Use o * como variável. Exemplos: doh (bloqueia apenas o termo doh) , doh* (bloqueia tnato doh quanto dohno) , do*h (bloqueia doh, dooh e dough).',
		'cancel_mailing_button' => 'Cancelar Enviador de Emails',
		'categories_introduction' => 'Para usar categorias, clique no botão \'Add Category\'.',
		'categories_not_shown' => 'Algumas perguntas estão em categorias que não serão mostradas.',
		'categories_title' => 'Categorias',
		'categories' => 'Categorias',
		'category_add_sub' => 'adicionar sub-categoria',
		'category_added' => 'Categoria adicionada',
		'category_already_used' => 'Isto já está em uso por uma categoria',
		'category_default_slug' => 'categoria-^',
		'category_description' => 'Descrição opcional de categoria:',
		'category_max_depth_x' => 'Algumas opções podem estar ocultas para prevenir que uma categoria tenha mais de ^ níveis.',
		'category_move_parent' => 'transferir para outra categoria-pai',
		'category_name_first' => 'Nome da primeira categoria:',
		'category_name' => 'Nome da categoria:',
		'category_no_add_subs_x' => 'Esta categoria não pode ter mais categorias porque já possui ^ níveis de profundidade.',
		'category_no_delete_subs' => 'Esta categoria não pode ser removida porque possui uma sub-categoria.',
		'category_no_sub_error' => '^q pergunta/s nesta categoria não possuem sub-categorias - ^1escolher sub-categoria^2',
		'category_no_sub_to' => 'Transferir perguntas em ^ sem sub-categorias para:',
		'category_no_subs' => 'Nada',
		'category_none_error' => '^q pergunta/s não possuem categorias - ^1escolher sub-categoria^2',
		'category_none_to' => 'Transferir perguntas sem categorias para:',
		'category_parent' => 'Categoria-pai:',
		'category_saved' => 'Categoria salva',
		'category_slug' => 'Categoria slug - Fragmento de URL:',
		'category_subs' => 'Sub-categorias:',
		'category_top_level' => 'Sem categoria-pai (primeiro nível)',
		'characters' => 'caracteres',
		'check_language_suffix' => ' - ^1conferir arquivos de idioma^2',
		'click_name_edit' => 'Páginas ou links customizados:',
		'database_cleanup' => 'Operações de limpeza de banco de dados',
		'delete_category_reassign' => 'Remover esta categoria e reclassicar as perguntas para:',
		'delete_category' => 'Remover esta categoria',
		'delete_field' => 'Remover este campo',
		'delete_hidden_complete' => 'Todos as publicações ocultas sem dependências foram removidas',
		'delete_hidden_note' => ' - todas as perguntas, respostas e comentários ocultos sem dependências',
		'delete_hidden' => 'Excluir todas as publicações ocultas',
		'delete_link' => 'Excluir este link',
		'delete_page' => 'Excluir esta página',
		'delete_stop' => 'Interromper exclusão',
		'delete_title' => 'Remover este título',
		'delete_widget_position' => 'Remover este widget desta posição',
		'edit_custom_page' => 'Editar página customizada',
		'edit_field' => ' - ^1editar campo^2',
		'edit_link' => ' - ^1editar link^2',
		'edit_page' => ' - ^1editar página^2',
		'edit_title' => ' - ^1editar título^2',
		'emails_per_minute' => 'emails por minuto',
		'emails_title' => 'Emails',
		'feed_link_example' => 'Exemplo de feed',
		'feed_link' => 'Feed',
		'feeds_title' => 'RSS feeds',
		'field_link_url' => 'URLs linkados',
		'field_multi_line' => 'Múltiplas linhas de texto',
		'field_name' => 'Nome do campo:',
		'field_single_line' => 'Linha única de texto',
		'field_type' => 'Tipo de conteúdo:',
		'first' => 'Primeiro',
		'flagged_title' => 'Denunciado',
		'from_anon' => 'De anônimo:',
		'from_users' => 'De usuários:',
		'general_title' => 'Geral',
		'hidden_answers_deleted' => 'Excluídas ^1 de ^2 respostas ocultas sem dependências...',
		'hidden_comments_deleted' => 'Excluídos ^1 de ^2 comentários ocultos...',
		'hidden_questions_deleted' => 'Excluídas ^1 de ^2 perguntas sem dependências...',
		'hotness_factors' => 'Importância relativa para a popularidade de perguntas:',
		'hidden_title' => 'Oculto',
		'installed_plugins' => 'Plugins instalados:',
		'ip_address_pages' => 'Página de endereços IP',
		'layout_title' => 'Aparência',
		'link_name' => 'Texto do link:',
		'link_new_window' => 'Abrir link em nova janela',
		'link_url' => 'Endereço do link - absoluto ou relativo à raiz do Q2A:',
		'lists_title' => 'Listas',
		'mailing_complete' => 'O envio de emails foi concluído',
		'mailing_explanation' => 'Usuários podem remover a inscrição ao envio de emails na página de usuário deles.',
		'mailing_progress' => 'Envio completo para ^1 de ^2 usuários...',
		'mailing_title' => 'Envio de emails',
		'mailing_unsubscribe' => 'Um link para remover a inscrição será acrescentado no rodapé de cada mensagem.',
		'maintenance_admin_only' => 'Seu site está em ^1manutenção^2 e está inacessível para usuários comuns.',
		'maximum_x' => ' (máximo ^)',
		'module_x_database_init' => 'Os módulos ^1 ^2 requerem ^3database initialization^4.',
		'most_flagged_title' => 'Conteúdo denunciado',
		'mysql_version' => 'Versão do MySQL:',
		'nav_links_explanation' => 'Mostrar links de navegação:',
		'nav_qa_is_home' => 'Início (linka para a página inicial)',
		'neat_urls_note' => ' (requer arquivo ^1htaccess^2)',
		'no_approve_found' => 'Nenhum conteúdo aguarda aprovação',
		'no_classification' => 'Nenhuma',
		'no_flagged_found' => 'Nenhum conteúdo denunciado encontrado',
		'no_hidden_found' => 'Nenhum conteúdo oculto encontrado',
		'no_image_gd' => 'A versão instalada do PHP foi compilada sem suporte a GD image, o que impede o envio direto de avatares pelos usuários.',
		'no_link' => 'Nenhum link',
		'no_multibyte' => 'A versão instalada do PHP foi compilada sem suporte a multibyte string. A busca será menos eficaz para caracteres não românicos.',
		'no_plugin_options' => 'Nenhum dos plugins instalados tem opções a exibir.',
		'no_privileges' => 'Somente administradores podem acessar esta página.',
		'not_logged_in' => 'Por favor ^1entre^2 como administrador para acessar esta página.',
		'opposite_main_menu' => 'Canto direito dos links do topo',
		'options_reset' => 'Opções restauradas',
		'options_saved' => 'Opções salvas',
		'options' => 'opções',
		'page_already_used' => 'Isto já está em uso por uma página',
		'page_content_html' => 'Conteúdo a ser divulgado na página - HTML permitido:',
		'page_default_slug' => 'página-^',
		'page_heading' => 'Cabeçalho a ser exibido no topo de página:',
		'page_name' => 'Nome da página (também usado para o link):',
		'page_slug' => 'Slug da página (Fragmento de URL):',
		'pages_explanation' => 'Clique no botão \'Add Page\' para acrescentar conteúdo customizado ao seu site Q2A, ou \'Add Link\' para linkar a sites externos.',
		'pages_title' => 'Páginas',
		'pause_mailing_button' => 'Interromper envio',
		'per_ip_hour' => 'por IP/hora',
		'per_user_hour' => 'por usuário/hora',
		'permissions_title' => 'Permissões',
		'permit_to_view' => 'Visível para:',
		'php_version' => 'Versão do PHP:',
		'pixels' => 'pixels',
		'plugin_module' => ' (módulo do plugin: ^)',
		'plugin_pages_explanation' => 'Páginas disponíveis via plugins:',
		'plugins_title' => 'Plugins',
		'points_defaults_shown' => 'Padrões mostrados abaixo mas AINDA NÃO APLICADOS:',
		'points_required' => 'Pontos necessários para receber título:',
		'points_title' => 'Pontos',
		'points' => 'pontos',
		'position' => 'Posição:',
		'posting_title' => 'Publicando',
		'profile_fields' => 'Campos adicionais no perfil do usuário:',
		'q2a_build_date' => 'Data da versão:',
		'q2a_db_size' => 'Tamanho do banco de dados:',
		'q2a_db_version' => 'Versão do banco de dados Q2A:',
		'q2a_latest_version' => 'Última versão:',
		'q2a_version' => 'Versão do Question2Answer:',
		'question_lists' => 'Lista de perguntas',
		'question_pages' => 'Páginas de perguntas',
		'recalc_categories_backpaths' => 'Recontando URL paths para ^1 de ^2 categorias...',
		'recalc_categories_complete' => 'Todas as categorias foram recalculadas com sucesso.',
		'recalc_categories_note' => ' - para publicações de categorias e contagem de categorias',
		'recalc_categories_recounting' => 'Recontando perguntas para ^1 de ^2 categorias...',
		'recalc_categories_updated' => 'Recontando para ^1 de ^2 publicações...',
		'recalc_categories' => 'Recontando categorias',
		'recalc_points_complete' => 'Todos os pontos de usuários foram recalculados com sucesso.',
		'recalc_points_note' => ' - para ranking de usuários e divulgação de pontos',
		'recalc_points_recalced' => 'Recalculados ^1 de ^2 usuários...',
		'recalc_points_usercount' => 'Estimando número total de usuários...',
		'recalc_points' => 'Recontando pontos de usuários',
		'recalc_posts_count' => 'Recuperando número total de perguntas, respostas e comentários...',
		'recalc_stop' => 'Interromper recontagem',
		'recent_approve_title' => 'Conteúdo recente aguardando aprovação',
		'recent_hidden_title' => 'Conteúdo recente oculto',
		'recount_posts_as_recounted' => 'Recontadas perguntas e popularidade para ^1 de ^2 publicações...',
		'recount_posts_complete' => 'Todas as publicações foram recontadas com sucesso.',
		'recount_posts_note' => ' - o número de respostas, votos e denúncias para cada publicação',
		'recount_posts_stop' => 'Interromper recontagem',
		'recount_posts_votes_recounted' => 'Recontados os votos e denúncias de ^1 de ^2 publicações...',
		'recount_posts' => 'Recontar publicações',
		'refill_events_complete' => 'Todos os eventos streams foram repreenchidos com sucesso',
		'refill_events_note' => ' - para cada lista de atualização de usuário\'s',
		'refill_events_refilled' => 'Repreenchidas ^1 de ^2 perguntas...',
		'refill_events' => 'Repreencher eventos streams',
		'reindex_content' => 'Reindexar conteúdo',
		'reindex_content_note' => ' - para pesquisa e sugestões de perguntas relacionadas',
		'reindex_content_stop' => 'Interromper reindexação',
		'reindex_pages_reindexed' => 'Reindexadas ^1 de ^2 páginas...',
		'reindex_posts_complete' => 'Todas as publicações foram reindexadas com sucesso.',
		'reindex_posts_reindexed' => 'Reindexados ^1 de ^2 publicações...',
		'reindex_posts_wordcounted' => 'Recontadas ^1 de ^2 palavras...',
		'requires_php_version' => 'Desativado - requer PHP ^ ou superior',
		'requires_q2a_version' => 'Desativado - requer Question2Answer ^ or superior',
		'reset_options_button' => 'Restaurar Padrões',
		'resume_mailing_button' => 'Continuar Envio de Emails',
		'save_options_button' => 'Salvar Opções',
		'save_recalc_button' => 'Salvar e Recontar',
		'send_test_button' => 'Enviar Teste para Mim',
		'show_defaults_button' => 'Mostrar Padrões',
		'slug_bad_chars' => 'O slug não pode conter esses caracteres: ^',
		'slug_reserved' => 'Este slug já está atribuído a outra página',
		'spam_title' => 'Spam',
		'start_mailing_button' => 'Iniciar Envio de Emails',
		'stats_title' => 'Estatísticas',
		'stop_recalc_warning' => 'Uma operação de limpeza do banco de dados está rodando. Se esta página for fechada agora, a operação será interrompida.',
		'tag_pages' => 'Páginas de Tags',
		'tags_and_categories' => 'Tags e Categorias',
		'tags_not_shown' => 'Algumas perguntas possuem tags que não serão mostradas.',
		'tags' => 'Tags',
		'test_sent_to_x' => 'A mensagem de teste foi enviada para ^',
		'title_already_used' => 'Isto já está em uso por outro título',
		'top_level_categories' => 'Categorias de primeiro nível:',
		'total_as' => 'Total de respostas:',
		'total_cs' => 'Total de comentários:',
		'total_qs' => 'Total de perguntas:',
		'unnamed_plugin' => 'Plugin sem nome',
		'upgrade_db' => 'O banco de dados do seu Question2Answer precisa ser ^1atualizado^2 para essa versão.',
		'url_format_note' => 'Opções com ^ estão funcionando para a configuração do seu site. Para um melhor search engine optimization (SEO), use a primeira opção ^ disponível.',
		'user_pages' => 'Páginas de usuários',
		'user_title' => 'Título de usuário - HTML permitido:',
		'user_titles' => 'Títulos de usuários com base em pontos:',
		'users_active' => 'Usuários ativos:',
		'users_must_have' => 'Usuários precisam ter',
		'users_posted' => 'Usuários com publicações:',
		'users_registered' => 'Usuários cadastrados:',
		'users_title' => 'Usuários',
		'users_voted' => 'Usuários que votaram:',
		'version_get_x' => 'recuperar ^',
		'version_requires_php' => '^1 requer PHP ^2', 
		'version_requires_q2a' => '^1 requer Q2A ^2', 
		'version_latest_unknown' => 'última versão desconhecida',
		'version_latest' => 'última',
		'viewing_title' => 'Visualização',
		'widget_all_pages' => 'Mostrar widget nesta posição em todas as páginas disponíveis',
		'widget_global_options' => ' - ^1opções^2',
		'widget_name' => 'Nome do widget:',
		'widget_no_positions' => 'Este widget já foi adicionado a todas as posições disponíveis.',
		'widget_not_available' => 'Este widgt não está disponível. Isto pode ter acontecido porque o plugin que providencia o widget não está mais instalado.',
		'widget_pages_explanation' => 'Mostrar o widget nesta posição para as seguintes páginas:',
		'widgets_explanation' => 'Widgets disponíveis:',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
